reference_updater library

Classes

ReferenceUpdater
This class is responsible for updating references to moved assets in Dart files. Recursively scans the 'lib' directory and replaces old paths with new ones based on the provided moved paths map.