asset_sorter library
Classes
- AssetSorter
- This class is responsible for organizing assets in the assets directory. Classifies files by extension into predefined folders (such as images, icons, etc.), moves files to their respective folders and cleans invalid directories or unnecessary subfolders.