AssetSorter class
This class is responsible for organizing assets in the assets directory. Classifies files by extension into predefined folders (such as images, icons, etc.), moves files to their respective folders and cleans invalid directories or unnecessary subfolders.
Constructors
- AssetSorter(Directory assetsDir, {bool excludeAudio = false})
Properties
- assetsDir → Directory
-
final
- excludeAudio → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sort(
) → Future< Map< String, String> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited