pubspec_updater library
Classes
- PubspecUpdater
- This class is responsible for updating the assets section in the pubspec.yaml file. Recursively scans the 'assets' directory to collect all asset folders, and updates the pubspec.yaml to include these paths in the Flutter configuration.