PubspecUpdater class
This class is responsible for updating the assets section in the pubspec.yaml file. Recursively scans the 'assets' directory to collect all asset folders, and updates the pubspec.yaml to include these paths in the Flutter configuration.
Constructors
- PubspecUpdater(File pubspecFile, {bool excludeAudio = false})
Properties
- excludeAudio → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pubspecFile → File
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateAssets(
) → void -
updateFonts(
YamlEditor editor, dynamic yaml) → void - Updates font references when files are in assets/fonts/
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited