ReferenceUpdater class
This class is responsible for updating references to moved assets in Dart files. Recursively scans the 'lib' directory and replaces old paths with new ones based on the provided moved paths map.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateReferences(
Map< String, String> movedPaths) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited